@@ -81,6 +81,7 @@ LOG = utils.make_a_logger()
 UNBUILDABLE_IMAGES = {
     'aarch64': {
         "bifrost-base",      # someone need to get upstream working first
+        "prometheus-msteams",  # no aarch64 binary
         "prometheus-mtail",  # no aarch64 binary
         "skydive-base",      # no aarch64 binary
     },
@@ -94,10 +95,12 @@ UNBUILDABLE_IMAGES = {
         "monasca-base",
         "monasca-thresh",
         "solum-base",
-        "vmtp",
         "zun-base",
     },
 
+    'source': {
+    },
+
     'centos': {
         "hacluster-pcs",         # Missing crmsh package
         "nova-spicehtml5proxy",  # Missing spicehtml5 package
@@ -106,8 +109,6 @@ UNBUILDABLE_IMAGES = {
     },
 
     'debian': {
-        "bifrost-base",  # tries to install 'mysql-server' which is not in
-                         # Debian 'buster' (fixed in Yoga)
         "qdrouterd",     # no qdrouterd package in Debian bullseye
     },
 
@@ -115,10 +116,6 @@ UNBUILDABLE_IMAGES = {
         "qdrouterd",  # There is no qdrouterd package for Ubuntu
     },
 
-    'debian+aarch64': {
-        "ovn-base",      # no binary package
-    },
-
     'ubuntu+aarch64': {
         "kibana",        # no binary package
         "monasca-base",  # 'confluent-kafka' requires newer libfdkafka-dev
@@ -310,14 +307,9 @@ class PushTask(DockerTask):
 
         # Since docker 3.0.0, the argument of 'insecure_registry' is removed.
         # To be compatible, set 'insecure_registry=True' for old releases.
-        # NOTE(frickler): The version check will fail for docker >= 6.0, but
-        # in that case we know that the workaround isn't needed.
-        try:
-            dc_running_ver = StrictVersion(docker.version)
-            if dc_running_ver < StrictVersion('3.0.0'):
-                kwargs['insecure_registry'] = True
-        except TypeError:
-            pass
+        dc_running_ver = StrictVersion(docker.version)
+        if dc_running_ver < StrictVersion('3.0.0'):
+            kwargs['insecure_registry'] = True
 
         for response in self.dc.push(image.canonical_name, **kwargs):
             if 'stream' in response:
@@ -369,16 +361,11 @@ class BuildTask(DockerTask):
         return followups
 
     def process_source(self, image, source):
-        dest_archive = os.path.join(image.path, source['name'] + '-archive')
+        if not source['enabled']:
+            self.logger.debug("Skipping disabled source %s", source['name'])
+            return
 
-        # NOTE(mgoddard): Change ownership of files to root:root. This
-        # avoids an issue introduced by the fix for git CVE-2022-24765,
-        # which breaks PBR when the source checkout is not owned by the
-        # user installing it. LP#1969096
-        def reset_userinfo(tarinfo):
-            tarinfo.uid = tarinfo.gid = 0
-            tarinfo.uname = tarinfo.gname = "root"
-            return tarinfo
+        dest_archive = os.path.join(image.path, source['name'] + '-archive')
 
         if source.get('type') == 'url':
             self.logger.debug("Getting archive from %s", source['source'])
@@ -424,6 +411,15 @@ class BuildTask(DockerTask):
                 image.status = Status.ERROR
                 return
 
+            # NOTE(mgoddard): Change ownership of files to root:root. This
+            # avoids an issue introduced by the fix for git CVE-2022-24765,
+            # which breaks PBR when the source checkout is not owned by the
+            # user installing it. LP#1969096
+            def reset_userinfo(tarinfo):
+                tarinfo.uid = tarinfo.gid = 0
+                tarinfo.uname = tarinfo.gname = "root"
+                return tarinfo
+
             with tarfile.open(dest_archive, 'w') as tar:
                 tar.add(clone_dir, arcname=os.path.basename(clone_dir),
                         filter=reset_userinfo)
@@ -434,8 +430,7 @@ class BuildTask(DockerTask):
             if os.path.isdir(source['source']):
                 with tarfile.open(dest_archive, 'w') as tar:
                     tar.add(source['source'],
-                            arcname=os.path.basename(source['source']),
-                            filter=reset_userinfo)
+                            arcname=os.path.basename(source['source']))
             else:
                 shutil.copyfile(source['source'], dest_archive)
 
@@ -468,14 +463,6 @@ class BuildTask(DockerTask):
 
     def builder(self, image):
 
-        def _test_malicious_tarball(archive, path):
-            tar_file = tarfile.open(archive, 'r|*')
-            for n in tar_file.getnames():
-                if not os.path.abspath(os.path.join(path, n)).startswith(path):
-                    tar_file.close()
-                    self.logger.error(f'Unsafe filenames in archive {archive}')
-                    raise ArchivingError
-
         def make_an_archive(items, arcname, item_child_path=None):
             if not item_child_path:
                 item_child_path = arcname
@@ -485,12 +472,12 @@ class BuildTask(DockerTask):
                 archive_path = self.process_source(image, item)
                 if image.status in STATUS_ERRORS:
                     raise ArchivingError
-                archives.append(archive_path)
+                if archive_path:
+                    archives.append(archive_path)
             if archives:
                 for archive in archives:
-                    _test_malicious_tarball(archive, items_path)
                     with tarfile.open(archive, 'r') as archive_tar:
-                        archive_tar.extractall(path=items_path)  # nosec
+                        archive_tar.extractall(path=items_path)
             else:
                 try:
                     os.mkdir(items_path)
@@ -505,18 +492,8 @@ class BuildTask(DockerTask):
                         image.status = Status.CONNECTION_ERROR
                         raise ArchivingError
             arc_path = os.path.join(image.path, '%s-archive' % arcname)
-
-            # NOTE(jneumann): Change ownership of files to root:root. This
-            # avoids an issue introduced by the fix for git CVE-2022-24765,
-            # which breaks PBR when the source checkout is not owned by the
-            # user installing it. LP#1969096
-            def reset_userinfo(tarinfo):
-                tarinfo.uid = tarinfo.gid = 0
-                tarinfo.uname = tarinfo.gname = "root"
-                return tarinfo
-
             with tarfile.open(arc_path, 'w') as tar:
-                tar.add(items_path, arcname=arcname, filter=reset_userinfo)
+                tar.add(items_path, arcname=arcname)
             return len(os.listdir(items_path))
 
         self.logger.debug('Processing')
@@ -678,7 +655,6 @@ class KollaWorker(object):
         self.base_tag = conf.base_tag
         self.install_type = conf.install_type
         self.tag = conf.tag
-        self.repos_yaml = conf.repos_yaml
         self.base_arch = conf.base_arch
         self.debian_arch = self.base_arch
         if self.base_arch == 'aarch64':
@@ -722,6 +698,12 @@ class KollaWorker(object):
                      "due to lack of packages for other architectures.")
             sys.exit(1)
 
+        if self.install_type == 'binary':
+            LOG.info("Building binary images is now deprecated. Consider "
+                     "switching to source ones.")
+            LOG.info("Build will continue in 5 seconds.")
+            time.sleep(5)
+
         self.image_prefix = self.base + '-' + self.install_type + '-'
         if self.conf.infra_rename:
             self.infra_image_prefix = self.base + '-infra-'
@@ -905,7 +887,6 @@ class KollaWorker(object):
                       'base_image': self.conf.base_image,
                       'base_distro_tag': self.base_tag,
                       'base_arch': self.base_arch,
-                      'repos_yaml': self.repos_yaml,
                       'use_dumb_init': self.use_dumb_init,
                       'base_package_type': self.base_package_type,
                       'debian_arch': self.debian_arch,
@@ -1240,6 +1221,7 @@ class KollaWorker(object):
                 installation['name'] = section
                 if installation['type'] == 'git':
                     installation['reference'] = self.conf[section]['reference']
+                installation['enabled'] = self.conf[section]['enabled']
             return installation
 
         all_sections = (set(self.conf._groups.keys()) |
