@@ -12,12 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# NOTE: jinja2 3.1.0 dropped contextfilter in favour of pass_context.
-try:
-    from jinja2 import pass_context
-except ImportError:
-    from jinja2 import contextfilter as pass_context
-
+from jinja2 import pass_context
 from jinja2 import Undefined
 
 
